@@ -6,9 +6,10 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.04.30 16:00:00                  #
+# Updated Date: 2024.12.14 08:00:00                  #
 # ================================================== #
 
+from typing import Optional, Any
 
 from PySide6.QtWidgets import QApplication, QFileDialog
 
@@ -40,7 +41,7 @@ class Batch:
             return
 
         # run asynchronous
-        self.window.ui.status("Importing assistants...please wait...")
+        self.window.update_status("Importing assistants...please wait...")
         self.window.core.gpt.assistants.importer.import_assistants()
 
     def import_stores(self, force: bool = False):
@@ -57,7 +58,7 @@ class Batch:
             )
             return
         # run asynchronous
-        self.window.ui.status("Importing vector stores...please wait...")
+        self.window.update_status("Importing vector stores...please wait...")
         self.window.core.assistants.store.truncate()  # clear all stores
         self.window.core.gpt.assistants.importer.import_vector_stores()
         self.window.controller.assistant.files.update()
@@ -95,7 +96,11 @@ class Batch:
             self.window.core.debug.log(e)
             self.window.ui.dialogs.alert(e)
 
-    def import_store_files(self, store_id: str, force: bool = False):
+    def import_store_files(
+            self,
+            store_id: str,
+            force: bool = False
+    ):
         """
         Sync files with API (store)
 
@@ -123,7 +128,7 @@ class Batch:
         """
         Truncate all files in API
 
-        :param force: if true, imports without confirmation
+        :param force: if True, imports without confirmation
         """
         if not force:
             self.window.ui.dialogs.confirm(
@@ -133,7 +138,7 @@ class Batch:
             )
             return
         # run asynchronous
-        self.window.ui.status("Removing files...please wait...")
+        self.window.update_status("Removing files...please wait...")
         QApplication.processEvents()
         self.window.core.gpt.assistants.importer.truncate_files()  # remove all files from API
 
@@ -142,7 +147,7 @@ class Batch:
         Truncate all files in API (store)
 
         :param idx: store index
-        :param force: if true, imports without confirmation
+        :param force: if True, imports without confirmation
         """
         store_id = self.window.controller.assistant.store.get_by_tab_idx(idx)
         self.truncate_store_files(store_id, force)
@@ -152,7 +157,7 @@ class Batch:
         Truncate all files in API (store)
 
         :param store_id: store ID
-        :param force: if true, imports without confirmation
+        :param force: if True, imports without confirmation
         """
         if store_id is None:
             self.window.ui.dialogs.alert(trans("dialog.assistant.store.alert.select"))
@@ -166,26 +171,34 @@ class Batch:
             )
             return
         # run asynchronous
-        self.window.ui.status("Removing files...please wait...")
+        self.window.update_status("Removing files...please wait...")
         QApplication.processEvents()
         self.window.core.gpt.assistants.importer.truncate_files(store_id)  # remove all files from API
 
-    def clear_store_files_by_idx(self, idx: int, force: bool = False):
+    def clear_store_files_by_idx(
+            self,
+            idx: int,
+            force: bool = False
+    ):
         """
         Clear files (store, local only)
 
         :param idx: store index
-        :param force: if true, clears without confirmation
+        :param force: if True, clears without confirmation
         """
         store_id = self.window.controller.assistant.store.get_by_tab_idx(idx)
         self.clear_store_files(store_id, force)
 
-    def clear_store_files(self, store_id: str = None, force: bool = False):
+    def clear_store_files(
+            self,
+            store_id: Optional[str] = None,
+            force: bool = False
+    ):
         """
         Clear files (store, local only)
 
         :param store_id: store ID
-        :param force: if true, clears without confirmation
+        :param force: if True, clears without confirmation
         """
         if store_id is None:
             self.window.ui.dialogs.alert(trans("dialog.assistant.store.alert.select"))
@@ -198,18 +211,18 @@ class Batch:
                 msg=trans('confirm.assistant.files.clear'),
             )
             return
-        self.window.ui.status("Clearing store files...please wait...")
+        self.window.update_status("Clearing store files...please wait...")
         QApplication.processEvents()
         self.window.core.assistants.files.truncate_local(store_id)  # clear files local
         self.window.controller.assistant.files.update()
-        self.window.ui.status("OK. All store files cleared.")
+        self.window.update_status("OK. All store files cleared.")
         self.window.ui.dialogs.alert(trans("status.finished"))
 
     def clear_files(self, force: bool = False):
         """
         Clear files (all, local only)
 
-        :param force: if true, clears without confirmation
+        :param force: if True, clears without confirmation
         """
         if not force:
             self.window.ui.dialogs.confirm(
@@ -218,18 +231,18 @@ class Batch:
                 msg=trans('confirm.assistant.files.clear'),
             )
             return
-        self.window.ui.status("Clearing files...please wait...")
+        self.window.update_status("Clearing files...please wait...")
         QApplication.processEvents()
         self.window.core.assistants.files.truncate_local()  # clear files local
         self.window.controller.assistant.files.update()
-        self.window.ui.status("OK. All files cleared.")
+        self.window.update_status("OK. All files cleared.")
         self.window.ui.dialogs.alert(trans("status.finished"))
 
     def clear_stores(self, force: bool = False):
         """
         Clear vector stores (local only)
 
-        :param force: if true, clears without confirmation
+        :param force: if True, clears without confirmation
         """
         if not force:
             self.window.ui.dialogs.confirm(
@@ -238,12 +251,12 @@ class Batch:
                 msg=trans('confirm.assistant.store.clear'),
             )
             return
-        self.window.ui.status("Clearing vector stores...please wait...")
+        self.window.update_status("Clearing vector stores...please wait...")
         QApplication.processEvents()
         self.window.core.assistants.store.truncate()  # clear all stores
         self.window.controller.assistant.files.update()
         self.window.controller.assistant.store.update()
-        self.window.ui.status("OK. All stores cleared.")
+        self.window.update_status("OK. All stores cleared.")
         self.window.controller.assistant.store.current = None
         self.window.controller.assistant.store.init()
 
@@ -251,7 +264,7 @@ class Batch:
         """
         Truncate vector stores in API
 
-        :param force: if true, truncates without confirmation
+        :param force: if True, truncates without confirmation
         """
         if not force:
             self.window.ui.dialogs.confirm(
@@ -261,7 +274,7 @@ class Batch:
             )
             return
         # run asynchronous
-        self.window.ui.status("Removing vector stores...please wait...")
+        self.window.update_status("Removing vector stores...please wait...")
         QApplication.processEvents()
         self.window.core.assistants.store.truncate()  # clear all stores
         self.window.core.gpt.assistants.importer.truncate_vector_stores()
@@ -274,7 +287,7 @@ class Batch:
         """
         Refresh all vector stores
 
-        :param force: if true, refresh without confirmation
+        :param force: if True, refresh without confirmation
         """
         if not force:
             self.window.ui.dialogs.confirm(
@@ -283,7 +296,7 @@ class Batch:
                 msg=trans('confirm.assistant.store.refresh'),
             )
             return
-        self.window.ui.status("Refreshing vector stores...please wait...")
+        self.window.update_status("Refreshing vector stores...please wait...")
         QApplication.processEvents()
         self.window.core.gpt.assistants.importer.refresh_vector_stores()
 
@@ -296,10 +309,10 @@ class Batch:
         self.window.controller.assistant.update()
         self.window.controller.assistant.store.update()
         self.window.controller.assistant.files.update()
-        self.window.ui.status("OK. Imported assistants: " + str(num) + ".")
+        self.window.update_status("OK. Imported assistants: " + str(num) + ".")
         self.window.ui.dialogs.alert(trans("status.finished"))
 
-    def handle_imported_assistants_failed(self, error: any):
+    def handle_imported_assistants_failed(self, error: Any):
         """
         Handle error on importing assistants
 
@@ -308,7 +321,7 @@ class Batch:
         self.window.core.debug.log(error)
         print("Error importing assistants")
         self.window.controller.assistant.update()
-        self.window.ui.status("Error importing assistants.")
+        self.window.update_status("Error importing assistants.")
         self.window.ui.dialogs.alert(error)
 
     def handle_refreshed_stores(self, num: int):
@@ -320,9 +333,9 @@ class Batch:
         self.window.controller.assistant.store.update_current()
         self.window.controller.assistant.store.update()
         self.window.ui.dialogs.alert(trans("status.finished"))
-        self.window.ui.status("OK. All stores refreshed.")
+        self.window.update_status("OK. All stores refreshed.")
 
-    def handle_refreshed_stores_failed(self, error: any):
+    def handle_refreshed_stores_failed(self, error: Any):
         """
         Handle error on refreshing stores
 
@@ -332,7 +345,7 @@ class Batch:
         print("Error refreshing stores", error)
         self.window.controller.assistant.files.update()
         self.window.controller.assistant.store.update()
-        self.window.ui.status("Error refreshing stores.")
+        self.window.update_status("Error refreshing stores.")
         self.window.ui.dialogs.alert(error)
 
     def handle_imported_stores(self, num: int):
@@ -343,11 +356,11 @@ class Batch:
         """
         self.window.controller.assistant.files.update()
         self.window.controller.assistant.store.update()
-        self.window.ui.status("OK. Imported stores: " + str(num) + ".")
+        self.window.update_status("OK. Imported stores: " + str(num) + ".")
         # alert on files import after stores
         # self.window.ui.dialogs.alert(trans("status.finished"))
 
-    def handle_imported_stores_failed(self, error: any):
+    def handle_imported_stores_failed(self, error: Any):
         """
         Handle error on importing stores
 
@@ -357,7 +370,7 @@ class Batch:
         self.window.controller.assistant.files.update()
         self.window.controller.assistant.store.update()
         print("Error importing stores", error)
-        self.window.ui.status("Error importing stores.")
+        self.window.update_status("Error importing stores.")
         self.window.ui.dialogs.alert(error)
 
     def handle_truncated_stores(self, num: int):
@@ -372,10 +385,10 @@ class Batch:
         self.window.controller.assistant.store.update()
         self.window.controller.assistant.store.current = None
         self.window.controller.assistant.store.init()
-        self.window.ui.status("OK. Removed stores: " + str(num) + ".")
+        self.window.update_status("OK. Removed stores: " + str(num) + ".")
         self.window.ui.dialogs.alert(trans("status.finished"))
 
-    def handle_truncated_stores_failed(self, error: any):
+    def handle_truncated_stores_failed(self, error: Any):
         """
         Handle error on truncating stores
 
@@ -385,7 +398,7 @@ class Batch:
         print("Error removing stores", error)
         self.window.controller.assistant.files.update()
         self.window.controller.assistant.store.update()
-        self.window.ui.status("Error removing stores.")
+        self.window.update_status("Error removing stores.")
         self.window.ui.dialogs.alert(error)
 
     def handle_imported_files(self, num: int):
@@ -395,10 +408,10 @@ class Batch:
         :param num: number of imported files
         """
         self.window.controller.assistant.files.update()
-        self.window.ui.status("OK. Imported files: " + str(num) + ".")
+        self.window.update_status("OK. Imported files: " + str(num) + ".")
         self.window.ui.dialogs.alert(trans("status.finished"))
 
-    def handle_imported_files_failed(self, error: any):
+    def handle_imported_files_failed(self, error: Any):
         """
         Handle error on importing files
 
@@ -407,23 +420,27 @@ class Batch:
         self.window.core.debug.log(error)
         self.window.controller.assistant.files.update()
         print("Error importing files")
-        self.window.ui.status("Error importing files.")
+        self.window.update_status("Error importing files.")
         self.window.ui.dialogs.alert(error)
 
-    def handle_truncated_files(self, store_id: str = None, num: int = 0):
+    def handle_truncated_files(
+            self,
+            store_id: Optional[str] = None,
+            num: int = 0
+    ):
         """
         Handle truncated (in API) files
 
         :param store_id: vector store ID
         :param num: number of truncated files
         """
-        self.window.ui.status("OK. Truncated files: " + str(num) + ".")
+        self.window.update_status("OK. Truncated files: " + str(num) + ".")
         if store_id is not None:
             self.window.controller.assistant.store.refresh_by_store_id(store_id)
         self.window.controller.assistant.files.update()
         self.window.ui.dialogs.alert(trans("status.finished"))
 
-    def handle_truncated_files_failed(self, error: any):
+    def handle_truncated_files_failed(self, error: Any):
         """
         Handle error on truncated files
 
@@ -432,7 +449,7 @@ class Batch:
         self.window.core.debug.log(error)
         print("Error truncating files")
         self.window.controller.assistant.files.update()
-        self.window.ui.status("Error truncating files.")
+        self.window.update_status("Error truncating files.")
         self.window.ui.dialogs.alert(error)
 
     def remove_store_from_assistants(self, store_id: str):
@@ -520,7 +537,7 @@ class Batch:
             return
 
         store_id = self.window.controller.assistant.store.current
-        self.window.ui.status("Uploading files...please wait...")
+        self.window.update_status("Uploading files...please wait...")
         QApplication.processEvents()
         self.window.core.gpt.assistants.importer.upload_files(store_id, self.files_to_upload)
         self.files_to_upload = []  # clear files
@@ -533,10 +550,10 @@ class Batch:
         """
         self.window.controller.assistant.files.update()
         self.window.controller.assistant.store.refresh_status()
-        self.window.ui.status("OK. Uploaded files: " + str(num) + ".")
+        self.window.update_status("OK. Uploaded files: " + str(num) + ".")
         self.window.ui.dialogs.alert("OK. Uploaded files: " + str(num) + ".")
 
-    def handle_uploaded_files_failed(self, error: any):
+    def handle_uploaded_files_failed(self, error: Any):
         """
         Handle error on uploading files
 
@@ -546,7 +563,7 @@ class Batch:
         print("Error uploading files")
         self.window.controller.assistant.files.update()
         self.window.controller.assistant.store.refresh_status()
-        self.window.ui.status("Error uploading files.")
+        self.window.update_status("Error uploading files.")
         self.window.ui.dialogs.alert(error)
 
     def handle_status_change(self, mode: str, msg: str):
@@ -556,4 +573,4 @@ class Batch:
         :param mode: status mode
         :param msg: status message
         """
-        self.window.ui.status(msg)
\ No newline at end of file
+        self.window.update_status(msg)
\ No newline at end of file
