@@ -6,11 +6,12 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.14 00:00:00                  #
+# Updated Date: 2025.07.13 01:00:00                  #
 # ================================================== #
 
-from typing import Any
+from typing import Any, Optional
 
+from pygpt_net.core.bridge import BridgeContext
 from pygpt_net.core.types import (
     MODE_AGENT,
     MODE_ASSISTANT,
@@ -37,7 +38,12 @@ class Output:
             self,
             ctx: CtxItem,
             mode: str,
-            stream_mode: bool = False
+            stream_mode: bool = False,
+            is_response: bool = False,
+            reply: bool = False,
+            internal: bool = False,
+            context: Optional[BridgeContext] = None,
+            extra: Optional[dict] = None
     ):
         """
         Handle response from LLM
@@ -45,15 +51,49 @@ class Output:
         :param ctx: CtxItem
         :param mode: mode (global)
         :param stream_mode: stream mode
+        :param is_response: Is response output
+        :param reply: is reply
+        :param internal: is internal command
+        :param context: BridgeContext (optional)
+        :param extra: Extra data (optional)
         """
         self.window.stateChanged.emit(self.window.STATE_BUSY)
 
         # if stream mode then append chunk by chunk
-        stream_enabled = self.window.core.config.get("stream")  # global stream enabled
+        end = True
         if stream_mode:  # local stream enabled
             if mode not in self.not_stream_modes:
-                self.window.controller.chat.stream.append(ctx)
+                end = False  # don't end stream mode, append chunk by chunk
+                self.window.controller.chat.stream.append(
+                    ctx=ctx,
+                    mode=mode,
+                    is_response=is_response,
+                    reply=reply,
+                    internal=internal,
+                    context=context,
+                    extra=extra,
+                )
 
+        if end:
+            self.handle_after(
+                ctx=ctx,
+                mode=mode,
+                stream=stream_mode
+            )
+
+    def handle_after(
+            self,
+            ctx: CtxItem,
+            mode: str,
+            stream: bool = False
+    ):
+        """
+        Handle response from LLM
+
+        :param ctx: CtxItem
+        :param mode: mode (global)
+        :param stream: stream mode
+        """
         # check if tool calls detected
         if ctx.tool_calls:
             # if not internal commands in a text body then append tool calls as commands (prevent double commands)
@@ -62,7 +102,7 @@ class Output:
                 if not isinstance(ctx.extra, dict):
                     ctx.extra = {}
                 ctx.extra["tool_calls"] = ctx.tool_calls
-                stream_mode = False  # disable stream mode, show tool calls at the end
+                stream = False  # disable stream mode, show tool calls at the end
                 self.log("Tool call received...")
             else:  # prevent execute twice
                 self.log("Ignoring tool call because command received...")
@@ -79,7 +119,8 @@ class Output:
         self.log("Appending output to chat window...")
 
         # only append output if not in stream mode, TODO: plugin output add
-        if not stream_mode:
+        stream_enabled = self.window.core.config.get('stream', False)
+        if not stream:
             if stream_enabled:  # use global stream settings here to persist previously added input
                 data = {
                     "meta": ctx.meta,
