@@ -6,13 +6,14 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.08.21 19:00:00                  #
+# Updated Date: 2024.12.14 08:00:00                  #
 # ================================================== #
 
 import datetime
 import os
+from typing import Any, List, Dict
 
-from PySide6.QtCore import Slot
+from PySide6.QtCore import Slot, QObject
 from PySide6.QtWidgets import QApplication
 
 from pygpt_net.core.idx.worker import IndexWorker
@@ -20,14 +21,16 @@ from pygpt_net.item.ctx import CtxMeta
 from pygpt_net.utils import trans
 
 
-class Indexer:
+class Indexer(QObject):
     def __init__(self, window=None):
         """
         Indexing controller
 
         :param window: Window instance
         """
+        super(Indexer, self).__init__()
         self.window = window
+        self.worker = None
         self.tmp_idx = None
 
     def update_explorer(self):
@@ -92,15 +95,15 @@ class Indexer:
         from_ts = meta.indexed
         self.window.update_status(trans('idx.status.indexing'))
 
-        worker = IndexWorker()
-        worker.window = self.window
-        worker.content = meta_id
-        worker.idx = idx
-        worker.type = "db_meta"
-        worker.from_ts = from_ts
-        worker.signals.finished.connect(self.handle_finished_db_meta)
-        worker.signals.error.connect(self.handle_error)
-        self.window.threadpool.start(worker)
+        self.worker = IndexWorker()
+        self.worker.window = self.window
+        self.worker.content = meta_id
+        self.worker.idx = idx
+        self.worker.type = "db_meta"
+        self.worker.from_ts = from_ts
+        self.worker.signals.finished.connect(self.handle_finished_db_meta)
+        self.worker.signals.error.connect(self.handle_error)
+        self.window.threadpool.start(self.worker)
         self.window.controller.idx.on_idx_start()  # on start
 
     def index_ctx_current(
@@ -143,20 +146,20 @@ class Indexer:
         :param idx: index name
         :param sync: sync mode
         """
-        worker = IndexWorker()
-        worker.window = self.window
-        worker.content = meta.id
-        worker.idx = idx
-        worker.type = "db_meta"
-        worker.from_ts = meta.indexed
-        worker.silent = True
-        worker.signals.finished.connect(self.handle_finished_db_meta)
-        worker.signals.error.connect(self.handle_error)
+        self.worker = IndexWorker()
+        self.worker.window = self.window
+        self.worker.content = meta.id
+        self.worker.idx = idx
+        self.worker.type = "db_meta"
+        self.worker.from_ts = meta.indexed
+        self.worker.silent = True
+        self.worker.signals.finished.connect(self.handle_finished_db_meta)
+        self.worker.signals.error.connect(self.handle_error)
 
         if sync:
-            worker.run()
+            self.worker.run()
         else:
-            self.window.threadpool.start(worker)
+            self.window.threadpool.start(self.worker)
 
     def index_ctx_from_ts_confirm(self, ts: int):
         """
@@ -201,23 +204,23 @@ class Indexer:
             )
             return
 
-        worker = IndexWorker()
-        worker.window = self.window
-        worker.content = ts
-        worker.idx = idx
-        worker.type = "db_current"
-        worker.silent = silent
-        worker.signals.finished.connect(self.handle_finished_db_current)
-        worker.signals.error.connect(self.handle_error)
-        self.window.threadpool.start(worker)
+        self.worker = IndexWorker()
+        self.worker.window = self.window
+        self.worker.content = ts
+        self.worker.idx = idx
+        self.worker.type = "db_current"
+        self.worker.silent = silent
+        self.worker.signals.finished.connect(self.handle_finished_db_current)
+        self.worker.signals.error.connect(self.handle_error)
+        self.window.threadpool.start(self.worker)
         self.window.controller.idx.on_idx_start()  # on start
 
     def index_path(
             self,
             path: str,
             idx: str = "base",
-            replace: bool = None,
-            recursive: bool = None
+            replace: bool = False,
+            recursive: bool = False
     ):
         """
         Index all files in path (threaded)
@@ -226,27 +229,26 @@ class Indexer:
         :param idx: index name
         :param replace: replace index
         :param recursive: recursive indexing
-        :param silent: silent mode
         """
         self.window.update_status(trans('idx.status.indexing'))
-        worker = IndexWorker()
-        worker.window = self.window
-        worker.content = path
-        worker.idx = idx
-        worker.type = "file"
-        worker.replace = replace
-        worker.recursive = recursive
-        worker.signals.finished.connect(self.handle_finished_file)
-        worker.signals.error.connect(self.handle_error)
-        self.window.threadpool.start(worker)
+        self.worker = IndexWorker()
+        self.worker.window = self.window
+        self.worker.content = path
+        self.worker.idx = idx
+        self.worker.type = "file"
+        self.worker.replace = replace
+        self.worker.recursive = recursive
+        self.worker.signals.finished.connect(self.handle_finished_file)
+        self.worker.signals.error.connect(self.handle_error)
+        self.window.threadpool.start(self.worker)
         self.window.controller.idx.on_idx_start()  # on start
 
     def index_paths(
             self,
-            paths: list,
+            paths: List[str],
             idx: str = "base",
-            replace: bool = None,
-            recursive: bool = None
+            replace: bool = False,
+            recursive: bool = False
     ):
         """
         Index all files in path (threaded)
@@ -257,17 +259,17 @@ class Indexer:
         :param recursive: recursive indexing
         """
         self.window.update_status(trans('idx.status.indexing'))
-        worker = IndexWorker()
-        worker.window = self.window
-        worker.content = paths
-        worker.idx = idx
-        worker.type = "files"
-        worker.replace = replace
-        worker.recursive = recursive
-        worker.silent = False
-        worker.signals.finished.connect(self.handle_finished_file)
-        worker.signals.error.connect(self.handle_error)
-        self.window.threadpool.start(worker)
+        self.worker = IndexWorker()
+        self.worker.window = self.window
+        self.worker.content = paths
+        self.worker.idx = idx
+        self.worker.type = "files"
+        self.worker.replace = replace
+        self.worker.recursive = recursive
+        self.worker.silent = False
+        self.worker.signals.finished.connect(self.handle_finished_file)
+        self.worker.signals.error.connect(self.handle_error)
+        self.window.threadpool.start(self.worker)
         self.window.controller.idx.on_idx_start()  # on start
 
     def index_all_files(
@@ -378,8 +380,8 @@ class Indexer:
             self,
             idx: str,
             loader: str,
-            params: dict,
-            config: dict,
+            params: Dict[str, Any],
+            config: Dict[str, Any],
             replace: bool = True,
     ):
         """
@@ -391,19 +393,19 @@ class Indexer:
         :param config: loader config
         :param replace: replace index
         """
-        worker = IndexWorker()
-        worker.window = self.window
-        worker.content = None
-        worker.loader = loader
-        worker.params = params
-        worker.config = config
-        worker.replace = replace
-        worker.silent = False
-        worker.idx = idx
-        worker.type = "web"
-        worker.signals.finished.connect(self.handle_finished_web)
-        worker.signals.error.connect(self.handle_error)
-        self.window.threadpool.start(worker)
+        self.worker = IndexWorker()
+        self.worker.window = self.window
+        self.worker.content = None
+        self.worker.loader = loader
+        self.worker.params = params
+        self.worker.config = config
+        self.worker.replace = replace
+        self.worker.silent = False
+        self.worker.idx = idx
+        self.worker.type = "web"
+        self.worker.signals.finished.connect(self.handle_finished_web)
+        self.worker.signals.error.connect(self.handle_error)
+        self.window.threadpool.start(self.worker)
         self.window.controller.idx.on_idx_start()  # on start
 
     def index_ctx_meta_remove(
@@ -454,7 +456,11 @@ class Indexer:
         idx_name = self.window.core.idx.get_by_idx(idx)
         self.clear(idx_name)
 
-    def clear(self, idx: str, force: bool = False):
+    def clear(
+            self,
+            idx: str,
+            force: bool = False
+    ):
         """
         Clear index data
 
@@ -495,7 +501,11 @@ class Indexer:
 
         self.window.tools.get("indexer").refresh()
 
-    def truncate(self, idx: str, force: bool = False):
+    def truncate(
+            self,
+            idx: str,
+            force: bool = False
+    ):
         """
         Truncate index data
 
@@ -540,7 +550,7 @@ class Indexer:
         self.window.tools.get("indexer").refresh()
 
     @Slot(object)
-    def handle_error(self, err: any):
+    def handle_error(self, err: Any):
         """
         Handle thread error signal
 
@@ -553,12 +563,12 @@ class Indexer:
         self.window.tools.get("indexer").refresh()
         self.window.controller.idx.on_idx_error()  # on error
 
-    @Slot(str, object, object)
+    @Slot(str, object, object, bool)
     def handle_finished_db_current(
             self,
             idx: str,
             num: int,
-            errors: list,
+            errors: List[str],
             silent: bool = False
     ):
         """
@@ -598,7 +608,7 @@ class Indexer:
             self,
             idx: str,
             num: int,
-            errors: list,
+            errors: List[str],
             silent: bool = False
     ):
         """
@@ -629,8 +639,8 @@ class Indexer:
     def handle_finished_file(
             self,
             idx: str,
-            files: dict,
-            errors: list,
+            files: Dict[str, str],
+            errors: List[str],
             silent: bool = False
     ):
         """
@@ -665,7 +675,7 @@ class Indexer:
             self,
             idx: str,
             num: int,
-            errors: list,
+            errors: List[str],
             silent: bool = False
     ):
         """
