@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.14 08:00:00                  #
+# Updated Date: 2025.07.13 08:00:00                  #
 # ================================================== #
 
 from typing import List
@@ -65,4 +65,19 @@ class Provider:
 
         :return: list of agent providers
         """
-        return self.get_ids()
\ No newline at end of file
+        return self.get_ids()
+
+    def get_choices(self) -> List[dict]:
+        """
+        Get agent providers choices
+
+        :return: list of agent providers choices
+        """
+        choices = []
+        for id in self.get_ids():
+            agent = self.get(id)
+            choices.append({id: agent.name})
+
+        # sort by name
+        choices.sort(key=lambda x: list(x.values())[0].lower())
+        return choices
