@@ -6,15 +6,28 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.06.30 02:00:00                  #
+# Updated Date: 2025.07.13 01:00:00                  #
 # ================================================== #
 
+import asyncio
 from typing import Optional, Dict, Any, List
 
 from llama_index.core.tools import FunctionTool
+from llama_index.core.workflow import Context
+from llama_index.core.agent.workflow import (
+    ToolCall,
+    ToolCallResult,
+    AgentStream,
+)
 
 from pygpt_net.core.bridge.context import BridgeContext
 from pygpt_net.core.bridge.worker import BridgeSignals
+from pygpt_net.core.types import (
+    AGENT_MODE_ASSISTANT,
+    AGENT_MODE_PLAN,
+    AGENT_MODE_STEP,
+    AGENT_MODE_WORKFLOW,
+)
 from pygpt_net.core.events import Event, KernelEvent
 from pygpt_net.item.ctx import CtxItem
 from pygpt_net.utils import trans
@@ -61,10 +74,20 @@ class Runner:
 
             # prepare agent
             model = context.model
+            agent_idx = extra.get("agent_idx", None)
+            self.window.core.agents.tools.context = context
+            self.window.core.agents.tools.agent_idx = agent_idx
+            system_prompt = context.system_prompt
             max_steps = self.window.core.config.get("agent.llama.steps", 10)
             tools = self.window.core.agents.tools.prepare(context, extra)
+            plugin_tools = self.window.core.agents.tools.get_plugin_tools(context, extra)
+            plugin_specs = self.window.core.agents.tools.get_plugin_specs(context, extra)
+            retriever_tool = self.window.core.agents.tools.get_retriever_tool(context, extra)
             history = self.window.core.agents.memory.prepare(context)
             llm = self.window.core.idx.llm.get(model, stream=False)
+            workdir = self.window.core.config.get_user_dir('data')
+            if self.window.core.plugins.get_option("cmd_code_interpreter", "sandbox_ipython"):
+                workdir = "/data"
 
             provider = None
             agent = None
@@ -72,18 +95,24 @@ class Runner:
                 kwargs = {
                     "context": context,
                     "tools": tools,
+                    "plugin_tools": plugin_tools,
+                    "plugin_specs": plugin_specs,
+                    "retriever_tool": retriever_tool,
                     "llm": llm,
                     "chat_history": history,
                     "max_iterations": max_steps,
                     "verbose": verbose,
+                    "system_prompt": system_prompt,
+                    "are_commands": self.window.core.config.get("cmd"),
+                    "workdir": workdir,
                 }
                 provider = self.window.core.agents.provider.get(id)
                 agent = provider.get_agent(self.window, kwargs)
                 if verbose:
-                    print("Using Agent: " + id + ", model: " + model.id)
+                    print("Using Agent: " + str(id) + ", model: " + str(model.id))
 
             if agent is None:
-                raise Exception("Agent not found: " + id)
+                raise Exception("Agent not found: " + str(id))
 
             # run agent
             mode = provider.get_mode()
@@ -94,18 +123,123 @@ class Runner:
                 "signals": signals,
                 "verbose": verbose,
             }
-            if mode == "plan":
+            if mode == AGENT_MODE_PLAN:
                 return self.run_plan(**kwargs)
-            elif mode == "step":
+            elif mode == AGENT_MODE_STEP:
                 return self.run_steps(**kwargs)
-            elif mode == "assistant":
+            elif mode == AGENT_MODE_ASSISTANT:
                 return self.run_assistant(**kwargs)
+            elif mode == AGENT_MODE_WORKFLOW:
+                kwargs["history"] = history
+                kwargs["llm"] = llm
+                return asyncio.run(self.run_workflow(**kwargs))
 
         except Exception as err:
             self.window.core.debug.error(err)
             self.error = err
             return False
 
+    async def run_agent_workflow(
+            self,
+            agent,
+            ctx,
+            query,
+            memory,
+            verbose=False,
+            item_ctx: Optional[CtxItem] = None,
+            signals: Optional[BridgeSignals] = None):
+        """
+        Run agent workflow
+        This method runs the agent's workflow, processes tool calls, and streams events.
+
+        :param agent: Agent instance
+        :param ctx: Context
+        :param query: Input query string
+        :param memory: Memory buffer for the agent
+        :param verbose: Verbose mode (default: False)
+        :param item_ctx: Optional CtxItem for additional context
+        :param signals: Optional BridgeSignals for communication
+        :return: handler for the agent workflow
+        """
+        handler = agent.run(query, ctx=ctx, memory=memory, verbose=verbose)
+        if verbose:
+            print(f"User:  {query}")
+        begin = True
+        async for event in handler.stream_events():
+            if self.is_stopped():
+                self.send_live_clear(item_ctx, signals)
+                break
+            if isinstance(event, ToolCallResult):
+                output = f"\n-----------\nCode execution result:\n{event.tool_output}"
+                if verbose:
+                    print(output)
+                self.send_live_append(item_ctx, signals, output, begin)
+            elif isinstance(event, ToolCall):
+                if "code" in event.tool_kwargs:
+                    output = f"\n-----------\nTool call code:\n{event.tool_kwargs['code']}"
+                    if verbose:
+                        print(output)
+                    self.send_live_append(item_ctx, signals, output, begin)
+            elif isinstance(event, AgentStream):
+                if verbose:
+                    print(f"{event.delta}", end="", flush=True)
+                self.send_live_append(item_ctx, signals, event.delta, begin)  # send stream to webview
+                begin = False
+
+        return await handler
+
+    async def run_workflow(
+            self,
+            agent: Any,
+            ctx: CtxItem,
+            prompt: str,
+            signals: BridgeSignals,
+            verbose: bool = False,
+            history: List[CtxItem] = None,
+            llm: Any = None,
+    ) -> bool:
+        """
+        Run agent workflow
+
+        :param agent: Agent instance
+        :param ctx: Input context
+        :param prompt: input text
+        :param signals: BridgeSignals
+        :param verbose: verbose mode
+        :param history: chat history
+        :param llm: LLM instance
+        :return: True if success
+        """
+        if self.is_stopped():
+            return True  # abort if stopped
+
+        agent_ctx = Context(agent)
+        memory = self.window.core.idx.chat.get_memory_buffer(history, llm)
+        self.set_busy(signals)
+        response = await self.run_agent_workflow(
+            agent=agent,
+            ctx=agent_ctx,
+            query=prompt,
+            memory=memory,
+            verbose=verbose,
+            item_ctx=ctx,
+            signals=signals,
+        )
+        response_ctx = self.add_ctx(ctx)
+        response_ctx.set_input("inp")
+        response_ctx.set_output(str(response))
+        response_ctx.extra["agent_output"] = True  # mark as output response
+        response_ctx.extra["agent_finish"] = True  # mark as finished
+
+        # if there are tool outputs, img, files, append it to the response context
+        self.window.core.agents.tools.append_tool_outputs(response_ctx)
+        self.send_live_clear(response_ctx, signals)
+
+        # send response
+        self.send_response(response_ctx, signals, KernelEvent.APPEND_DATA)
+        self.set_idle(signals)
+        return True
+
     def run_steps(
             self,
             agent: Any,
@@ -596,6 +730,49 @@ class Runner:
         ctx.live = True
         return ctx
 
+    def send_live_append(
+            self,
+            ctx: CtxItem,
+            signals: BridgeSignals,
+            text: str,
+            begin: bool=False
+    ):
+        """
+        Send live response to chat window (BridgeSignals)
+
+        :param ctx: CtxItem
+        :param signals: BridgeSignals
+        :param text: text to send
+        :param begin: True if it is the beginning of the text
+        """
+        context = BridgeContext()
+        context.ctx = ctx
+        extra = {
+            "chunk": str(text),
+            "begin": begin,
+        }
+        event = KernelEvent(KernelEvent.LIVE_APPEND, {
+            'context': context,
+            'extra': extra,
+        })
+        signals.response.emit(event)
+
+    def send_live_clear(self, ctx: CtxItem, signals: BridgeSignals):
+        """
+        Send live clear response to chat window (BridgeSignals)
+
+        :param ctx: CtxItem
+        :param signals: BridgeSignals
+        """
+        context = BridgeContext()
+        context.ctx = ctx
+        extra = {}
+        event = KernelEvent(KernelEvent.LIVE_CLEAR, {
+            'context': context,
+            'extra': extra,
+        })
+        signals.response.emit(event)
+
     def send_response(
             self,
             ctx: CtxItem,
