@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.06.30 02:00:00                  #
+# Updated Date: 2025.07.10 23:00:00                  #
 # ================================================== #
 
 import copy
@@ -348,6 +348,8 @@ class BasePlugin(QObject):
         :param ctx: context (CtxItem)
         :return: True if async execution is allowed
         """
+        if ctx.async_disabled:
+            return False
         return self.window.controller.kernel.async_allowed(ctx)
 
     def log(self, msg: str):
