@@ -23,17 +23,17 @@ class Config(BaseConfig):
 
         :param plugin: plugin instance
         """
-        prompt = 'IMAGE GENERATION: Whenever I provide a basic idea or concept for an image, such as \'a picture of ' \
+        prompt = 'IMAGE GENERATION: Whenever I provide a basic idea or concept for an image, such as \'give me a picture of ' \
                  'mountains\', I want you to ALWAYS translate it into English and expand and elaborate on this idea. ' \
-                 'Use your  knowledge and creativity to add details that would make the image more vivid and ' \
+                 'Use your knowledge and creativity to add details that would make the image more vivid and ' \
                  'interesting. This could include specifying the time of day, weather conditions, surrounding ' \
                  'environment, and any additional elements that could enhance the scene. Your goal is to create a ' \
-                 'detailed and descriptive prompt that provides DALL-E  with enough information to generate a rich ' \
-                 'and visually appealing image. Remember to maintain the original  intent of my request while ' \
+                 'detailed and descriptive prompt that provides DALL-E with enough information to generate a rich ' \
+                 'and visually appealing image. Remember to maintain the original intent of my request while ' \
                  'enriching the description with your imaginative details. HOW TO START IMAGE GENERATION: to start ' \
-                 'image generation return to me prepared prompt in JSON format, all in one line,  using following ' \
-                 'syntax: ~###~{"cmd": "image", "params": {"query": "your query here"}}~###~. Use ONLY this syntax ' \
-                 'and remember to surround JSON string with ~###~. DO NOT use any other syntax. Use English in the ' \
+                 'image generation return to me prepared prompt in JSON format, all in one line, using the following ' \
+                 'syntax: <tool>...</tool>, example: <tool>{"cmd": "image", "params": {"query": "your query here"}}</tool>. Use ONLY this syntax ' \
+                 'and remember to surround JSON string with <tool> tags. DO NOT use any other syntax. Use English in the ' \
                  'generated JSON command, but conduct all the remaining parts of the discussion with me in the ' \
                  'language in which I am speaking to you. The image will be generated on my machine  immediately ' \
                  'after the command is issued, allowing us to discuss the photo once it has been created.  Please ' \
