@@ -86,7 +86,11 @@ class TempProvider(BaseStore):
                 return True
         return False
 
-    def create(self, id: str):
+    def create(
+            self,
+            id: str,
+            embed_model: Optional = None
+    ):
         """
         Create empty index
 
@@ -95,13 +99,13 @@ class TempProvider(BaseStore):
         if self.persist:
             path = self.get_path(id)
             if not os.path.exists(path):
-                index = self.index_from_empty()  # create empty index
+                index = self.index_from_empty(embed_model)  # create empty index
                 self.store(
                     id=id,
                     index=index,
                 )
         else:
-            self.indexes[id] = self.index_from_empty()
+            self.indexes[id] = self.index_from_empty(embed_model)
 
     def get(
             self,
@@ -118,7 +122,7 @@ class TempProvider(BaseStore):
         :return: index instance
         """
         if not self.exists(id):
-            self.create(id)
+            self.create(id, embed_model)
         path = self.get_path(id)
 
         if self.persist:
